summaryrefslogtreecommitdiffstats
path: root/Source/CursesDialog/cmCursesMainForm.h
diff options
context:
space:
mode:
authorAndy Cedilnik <andy.cedilnik@kitware.com>2002-11-19 18:09:16 (GMT)
committerAndy Cedilnik <andy.cedilnik@kitware.com>2002-11-19 18:09:16 (GMT)
commit1d39833446340e262020c83d9ef3124da6a1e3f7 (patch)
tree46616ea0a73eb5210f6bea44eaf14bee7541d777 /Source/CursesDialog/cmCursesMainForm.h
parent0cb9343e833a84d9835216abe6219248a8c787c8 (diff)
downloadCMake-1d39833446340e262020c83d9ef3124da6a1e3f7.zip
CMake-1d39833446340e262020c83d9ef3124da6a1e3f7.tar.gz
CMake-1d39833446340e262020c83d9ef3124da6a1e3f7.tar.bz2
Add progress to ccmake
Diffstat (limited to 'Source/CursesDialog/cmCursesMainForm.h')
-rw-r--r--Source/CursesDialog/cmCursesMainForm.h20
1 files changed, 13 insertions, 7 deletions
diff --git a/Source/CursesDialog/cmCursesMainForm.h b/Source/CursesDialog/cmCursesMainForm.h
index 9e19919..3281e18 100644
--- a/Source/CursesDialog/cmCursesMainForm.h
+++ b/Source/CursesDialog/cmCursesMainForm.h
@@ -22,6 +22,7 @@
#include "cmCursesStandardIncludes.h"
class cmCursesCacheEntryComposite;
+class cmCursesWidget;
class cmake;
/** \class cmCursesMainForm
@@ -65,17 +66,21 @@ public:
};
/**
- * This method should normally called only by the form.
- * The only exception is during a resize.
+ * This method should normally be called only by the form. The only
+ * exception is during a resize. The optional argument specifies the
+ * string to be displayed in the status bar.
*/
- virtual void UpdateStatusBar();
+ virtual void UpdateStatusBar() { this->UpdateStatusBar(0); }
+ virtual void UpdateStatusBar(const char* message);
/**
* Display current commands and their keys on the toolbar.
* This method should normally called only by the form.
* The only exception is during a resize.
*/
- void PrintKeys();
+ void PrintKeys(int process = 0);
/**
* During a CMake run, an error handle should add errors
@@ -101,6 +106,7 @@ public:
/**
* Progress callback
*/
+ static void UpdateProgressOld(const char *msg, float prog, void*);
static void UpdateProgress(const char *msg, float prog, void*);
protected:
@@ -65,17 +66,21 @@ public:
/**
- * Display current commands and their keys on the toolbar.
- * This method should normally called only by the form.
- * The only exception is during a resize.
+ * Display current commands and their keys on the toolbar. This
+ * method should normally called only by the form. The only
+ * exception is during a resize. If the optional argument process is
+ * specified and is either 1 (configure) or 2 (generate), then keys
+ * will be displayed accordingly.
*/